@@ -1,7 +1,7 @@
 """
 Type annotations for amplifybackend service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/literals.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/literals/)
 
 Usage::
 
@@ -34,8 +34,11 @@ __all__ = (
     "ServiceType",
     "SignInMethodType",
     "StatusType",
+    "AmplifyBackendServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
+    "RegionName",
 )
 
 
@@ -75,6 +78,7 @@ ResolutionStrategyType = Literal["AUTOMERGE", "LAMBDA", "NONE", "OPTIMISTIC_CONC
 ServiceType = Literal["COGNITO"]
 SignInMethodType = Literal["EMAIL", "EMAIL_AND_PHONE_NUMBER", "PHONE_NUMBER", "USERNAME"]
 StatusType = Literal["LATEST", "STALE"]
+AmplifyBackendServiceName = Literal["amplifybackend"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -108,6 +112,7 @@ ServiceName = Literal[
     "ce",
     "chime",
     "chime-sdk-identity",
+    "chime-sdk-meetings",
     "chime-sdk-messaging",
     "cloud9",
     "cloudcontrol",
@@ -362,4 +367,30 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal["list_backend_jobs"]
+RegionName = Literal[
+    "ap-northeast-1",
+    "ap-northeast-2",
+    "ap-south-1",
+    "ap-southeast-1",
+    "ap-southeast-2",
+    "ca-central-1",
+    "eu-central-1",
+    "eu-west-1",
+    "eu-west-2",
+    "us-east-1",
+    "us-east-2",
+    "us-west-2",
+]
