@@ -1,19 +1,20 @@
 """
 Type annotations for amplifybackend service client paginators.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/paginators.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/paginators/)
 
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
 
-    from mypy_boto3_amplifybackend import AmplifyBackendClient
+    from mypy_boto3_amplifybackend.client import AmplifyBackendClient
     from mypy_boto3_amplifybackend.paginator import (
         ListBackendJobsPaginator,
     )
 
-    client: AmplifyBackendClient = boto3.client("amplifybackend")
+    session = Session()
+    client: AmplifyBackendClient = session.client("amplifybackend")
 
     list_backend_jobs_paginator: ListBackendJobsPaginator = client.get_paginator("list_backend_jobs")
     ```
@@ -40,8 +41,8 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
 
 class ListBackendJobsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.8/reference/services/amplifybackend.html#AmplifyBackend.Paginator.ListBackendJobs)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/paginators.html#listbackendjobspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/amplifybackend.html#AmplifyBackend.Paginator.ListBackendJobs)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/paginators/#listbackendjobspaginator)
     """
 
     def paginate(
@@ -52,9 +53,9 @@ class ListBackendJobsPaginator(Boto3Paginator):
         JobId: str = ...,
         Operation: str = ...,
         Status: str = ...,
-        PaginationConfig: PaginatorConfigTypeDef = ...
+        PaginationConfig: "PaginatorConfigTypeDef" = ...
     ) -> _PageIterator[ListBackendJobsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.8/reference/services/amplifybackend.html#AmplifyBackend.Paginator.ListBackendJobs.paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/paginators.html#listbackendjobspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/amplifybackend.html#AmplifyBackend.Paginator.ListBackendJobs.paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/paginators/#listbackendjobspaginator)
         """
